import QtQuick 2.1
import qb.components 1.0
import BasicUIControls 1.0
import QtQuick.XmlListModel 2.0

Tile {
    property alias progress: config.status

    onProgressChanged: generate()

    onClicked: {
        if (app.wifiScreen) app.wifiScreen.load();
    }

    function init() {
        app.settingsChanged.connect(generate);
    }

    function encode(str) {                            
        if (str.search(/[^0-9a-f]/i) < 0) {                               
            // String looks like a hex number                             
            return '"' + str + '"';                                       
        } else {                                                          
            // Escape special characters                                  
            return str.replace(/[\\";,:]/g, "\\$&");                      
        }                                                                    
    }

    function generate() {
        var network, password, security, hidden;
        if (config.status == XmlListModel.Ready) {
            if (app.settings.internal) {
                network = config.get(0).essid;
                password = config.get(0).psk;
                security = config.get(0).auth == "WEP" ? "WEP" : "PSA"
                hidden = config.get(0).visibility === "0";
            } else {
                network = app.settings.network;
                password = app.settings.password;
                security = app.settings.security;
                hidden = app.settings.hidden;
            }
            var str = "WIFI:";
            str += "T:" + security + ";"
            str += "S:" + encode(network) + ";"
            str += "P:" + encode(password) + ";"
            if (hidden === true) {
                str += "H:true"
            }
            str += ";"
            qrCode.content = str;
        }
    }

    XmlListModel {
        id: config
        source: "file:///HCBv2/config/config_hcb_netcon.xml"
        query: "/Config/device/interfaceSettings/wifi_essid/.."
        XmlRole {
            name: "essid"
            query: "wifi_essid/string()"
        }
        XmlRole {
            name: "psk"
            query: "wifi_key/string()"
        }
        XmlRole {
            name: "auth"
            query: "wifi_auth/string()"
        }
        XmlRole {
            name: "visibility"
            query: "../visibility/string()"
        }
    }

    Text {
        text: qsTranslate("WifiApp", "WiFi")
        font {
            family: qfont.bold.name
            pointSize: 18
        }
	anchors {
            horizontalCenter: parent.horizontalCenter
            top: parent.top
            topMargin: 10
        }
    }

    QrCode {
        id: qrCode
        anchors {
	    horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: 12
        }
        width: isNxt ? 125 : 100
        height: width
    }
}
